@@ -33,12 +33,11 @@ struct _GVirConfigDomainOsPrivate
     gboolean unused;
 };
 
-G_DEFINE_TYPE(GVirConfigDomainOs, gvir_config_domain_os, GVIR_CONFIG_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE(GVirConfigDomainOs, gvir_config_domain_os, GVIR_CONFIG_TYPE_OBJECT);
 
 
-static void gvir_config_domain_os_class_init(GVirConfigDomainOsClass *klass)
+static void gvir_config_domain_os_class_init(GVirConfigDomainOsClass *klass G_GNUC_UNUSED)
 {
-    g_type_class_add_private(klass, sizeof(GVirConfigDomainOsPrivate));
 }
 
 
@@ -307,6 +306,13 @@ void gvir_config_domain_os_set_arch(GVirConfigDomainOs *os, const char *arch)
     xmlNewProp(os_type_node, (xmlChar*)"arch", (xmlChar*)arch);
 }
 
+const char *gvir_config_domain_os_get_machine(GVirConfigDomainOs *os)
+{
+    return gvir_config_object_get_attribute(GVIR_CONFIG_OBJECT(os),
+                                            "type",
+                                            "machine");
+}
+
 void gvir_config_domain_os_set_machine(GVirConfigDomainOs *os, const char *machine)
 {
     xmlNodePtr os_node;
@@ -322,3 +328,32 @@ void gvir_config_domain_os_set_machine(GVirConfigDomainOs *os, const char *machi
 
     xmlNewProp(os_type_node, (xmlChar*)"machine", (xmlChar*)machine);
 }
+
+void gvir_config_domain_os_set_firmware(GVirConfigDomainOs *os, GVirConfigDomainOsFirmware firmware)
+{
+    xmlNodePtr node;
+    const gchar *firmware_str;
+
+    g_return_if_fail(GVIR_CONFIG_IS_DOMAIN_OS(os));
+
+    node = gvir_config_object_get_xml_node(GVIR_CONFIG_OBJECT(os));
+    g_return_if_fail(node != NULL);
+
+    firmware_str = gvir_config_genum_get_nick(GVIR_CONFIG_TYPE_DOMAIN_OS_FIRMWARE,
+                   firmware);
+    g_return_if_fail(firmware_str != NULL);
+
+    xmlNewProp(node, (xmlChar*)"firmware", (xmlChar*)firmware_str);
+}
+
+GVirConfigDomainOsFirmware gvir_config_domain_os_get_firmware(GVirConfigDomainOs *os)
+{
+    g_return_val_if_fail(GVIR_CONFIG_IS_DOMAIN_OS(os),
+                         GVIR_CONFIG_DOMAIN_OS_FIRMWARE_BIOS);
+
+    return gvir_config_object_get_attribute_genum
+            (GVIR_CONFIG_OBJECT(os),
+             NULL, "firmware",
+             GVIR_CONFIG_TYPE_DOMAIN_OS_FIRMWARE,
+             GVIR_CONFIG_DOMAIN_OS_FIRMWARE_BIOS);
+}
