@@ -42,7 +42,7 @@ struct _GVirNetworkPrivate
     gchar uuid[VIR_UUID_STRING_BUFLEN];
 };
 
-G_DEFINE_TYPE(GVirNetwork, gvir_network, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE(GVirNetwork, gvir_network, G_TYPE_OBJECT);
 
 
 enum {
@@ -105,8 +105,6 @@ static void gvir_network_finalize(GObject *object)
     GVirNetwork *network = GVIR_NETWORK(object);
     GVirNetworkPrivate *priv = network->priv;
 
-    g_debug("Finalize GVirNetwork=%p", network);
-
     virNetworkFree(priv->handle);
 
     G_OBJECT_CLASS(gvir_network_parent_class)->finalize(object);
@@ -143,15 +141,11 @@ static void gvir_network_class_init(GVirNetworkClass *klass)
                                                        G_PARAM_WRITABLE |
                                                        G_PARAM_CONSTRUCT_ONLY |
                                                        G_PARAM_STATIC_STRINGS));
-
-    g_type_class_add_private(klass, sizeof(GVirNetworkPrivate));
 }
 
 
 static void gvir_network_init(GVirNetwork *network)
 {
-    g_debug("Init GVirNetwork=%p", network);
-
     network->priv = GVIR_NETWORK_GET_PRIVATE(network);
 }
 
@@ -233,7 +227,6 @@ GVirConfigNetwork *gvir_network_get_config(GVirNetwork *network,
  * @network: the network
  * @mac: (allow-none): The optional ASCII formatted MAC address of an interface
  * @flags: placeholder for flags, must be 0
- *
  * @err: Place-holder for possible errors
  *
  * This function fetches leases info of guests in the specified network. If the
