@@ -38,7 +38,7 @@ struct _GVirNodeDevicePrivate
     virNodeDevicePtr handle;
 };
 
-G_DEFINE_TYPE(GVirNodeDevice, gvir_node_device, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE(GVirNodeDevice, gvir_node_device, G_TYPE_OBJECT);
 
 
 enum {
@@ -101,8 +101,6 @@ static void gvir_node_device_finalize(GObject *object)
     GVirNodeDevice *device = GVIR_NODE_DEVICE(object);
     GVirNodeDevicePrivate *priv = device->priv;
 
-    g_debug("Finalize GVirNodeDevice=%p", device);
-
     virNodeDeviceFree(priv->handle);
 
     G_OBJECT_CLASS(gvir_node_device_parent_class)->finalize(object);
@@ -127,15 +125,11 @@ static void gvir_node_device_class_init(GVirNodeDeviceClass *klass)
                                                        G_PARAM_WRITABLE |
                                                        G_PARAM_CONSTRUCT_ONLY |
                                                        G_PARAM_STATIC_STRINGS));
-
-    g_type_class_add_private(klass, sizeof(GVirNodeDevicePrivate));
 }
 
 
 static void gvir_node_device_init(GVirNodeDevice *device)
 {
-    g_debug("Init GVirNodeDevice=%p", device);
-
     device->priv = GVIR_NODE_DEVICE_GET_PRIVATE(device);
 }
 
